c---------------------------------------------------------------------------
      subroutine calc_era()
c     A. Raltson, "A First Course in Numerical Analysis", McGraw-Hill,
c     New York, 1965. Sec. 7.7-2, pages 294-296 
c---------------------------------------------------------------------------
      use datos, only : stdout1, faterr, rank, m, n, cof, coft, cofera,
     & resid, numera, denera, enera, R, t1, t2, gamm, tcheb, alpha,
     & warning
      use libreria, only : error
      implicit real*8 (a-h,o-z)
c.....LOCAL VARIABLES:
      integer :: j,i,k,par,init
      real*8 :: x,dmn,numb,dij,sumn,sumd,TINY,rold
      parameter (TINY=1.d-20)
      data rold /1.d30/

c     Initializations
       resid=0.d0 
       numera=0.d0
       x=1.d0/R
       par=mod(rank,2)
c     Obtain Pade aproximant (m,n) and dmn term
       coft=cof ! Copy coefficients in coft
       call calc_pade (coft,m,n,resid) ! Pade aproximant (m,n)
       call calc_dvalue (coft,m,n,dmn) ! dmn term
c     Obtain Chebysev coefficients tcheb in T(rank) Chebyshev
c     polynomials
       call chebyshev ()
c     Obtain gamm(0) term 
       allocate (gamm(0:m+n-1),stat=ier)
       if (ier.ne.0)
     &  call error ('calc_era', 'Cannot allocate gamm', faterr)
       if (par.eq.0) then ! rank is even
        numb=alpha**rank
        gamm(0)=-dmn*numb*tcheb(0)*2.d0**(-(m+n))
        numera=gamm(0)
       else ! rank is odd
        gamm(0)=0.d0
       endif
c     Calculate initial values for ERA aproximant
       sumn=coft(m+1)
       do j=m,1,-1
        sumn=sumn*x+coft(j) !Horner's rule
       enddo
       numera=numera+sumn
       sumd=0.d0
       do j=m+n+1,m+2,-1
        sumd=(sumd+coft(j))*x !Horner's rule
       enddo
       denera=1.d0+sumd
c     Obtain a sequence of Pade approximations
        if (par.eq.0) then  ! rank is even --> j odd
         init=1 
        else  ! rank is odd --> j even
         init=0
        endif
        do j=init,m+n-2,2
c        coefficients for Rational function:
c        R_i,j-i(x)=P_i(x)/Q_j-i(x)
         allocate (cofera(j+1), stat=ier)
         if (ier.ne.0)
     &    call error ('calc_era', 'Cannot allocate cofera', faterr)
         do i=0,m
          if (i.eq.1.and.(j-i).eq.1) goto 2 ! singular matrix in ludcmp
          if ((j-i).ge.0.and.(j-i).le.n) then
           !Copy coefficients in cofera
           do k=0,i 
            cofera(k+1)=cof(k+1)
           enddo
           do k=1,j-i 
            cofera(i+1+k)=cof(i+1+k)
           enddo
           call calc_pade(cofera,i,j-i,resid)
           call calc_dvalue(cofera,i,j-i,dij)
           if (resid.ge.rold) goto 2 !select i such that resid is
                                     !minimized
           if (dij.le.TINY) goto 2 !this procedure will fail if dij=0
           gamm(j+1)=dmn*alpha**(m+n-j)*tcheb(j+1)*2.d0**(-(m+n))
     &       /dij 
           sumn=cofera(i+1)
           do k=i,1,-1
            sumn=sumn*x+cofera(k) !Horner's rule
           enddo
           sumd=0.d0
           do k=j+1,i+2,-1
            sumd=(sumd+cofera(k))*x !Horner's rule
           enddo
           rold=resid
          endif
 2        continue
         enddo
         deallocate(cofera, stat=ier)
         if (ier.ne.0)
     &    call error ('calc_era', 'Cannot deallocate cofera', faterr)
         if (rold.eq.1.d30) then
          call error ('calc_era', 'Residual vector is equal or greather
     & than 1.e30 in all cases', warning)
          write (*,*) 'j value =',j
         else
          numera=numera+sumn*gamm(j+1)
          denera=denera+(1.d0+sumd)*gamm(j+1)
         endif
        enddo
c      Obtain ERA aproximant (m,n)
       enera=numera/denera       
       deallocate (gamm, stat=ier)
       if (ier.ne.0)
     &  call error ('calc_era', 'Cannot deallocate gamm', faterr)
c        
c
c-----End of the subroutine
c
      return
      end subroutine
