c----------------------------------------------------------------------      
      subroutine calc_pade(cof,m,n,resid)
c    Given cof(m+n+1), the leading terms in the power series 
c    expansion of a function f(x), solve the linear Pade equations
c    to return the coefficients of a rational function 
c    approximation to the same function, namely (cof(1)+cof(2)*x+...
c    +cof(m+1)x**m)/(1+cof(m+2)*x+...+cof(m+n+1)*x**n). The value 
c    'resid' is the norm of the residual vector; a small indicates
c    a well convergend solution.
c    W. H. Press, S. A. Teukolsky, W. T. Vetterling, B. P. Flanney,
c    "Numerical Recipes in Fortran", 2 edition (1994).
c----------------------------------------------------------------------
      use libreria, only : ludcmp, lubksb, mprove
      integer:: m,n
      real*8 :: resid
      real*8 :: cof(n+m+1)
c.....LOCAL VARIABLES:
      real*8 :: BIG
      parameter (BIG=1.e30)
      integer :: j,k,indx(n)
      real*8 :: d,rr,rrold,sum,q(n,n),qlu(n,n),x(n),y(n),
     &       z(n), v(m)
C     USES lubksb,ludcmp,mprove

c     Set up matrix for solving
      do j=1,n
        x(j)=cof(m+j+1)
        y(j)=x(j) !use in mprove
        do k=1,n
          q(j,k)=cof(j-k+m+1) !use in mprove
          qlu(j,k)=q(j,k) 
        enddo
      enddo
c     Solve by LU descomposition and forward substitution 
c     and backsustitution
      call ludcmp(qlu,n,indx)
      call lubksb(qlu,n,indx,x)
      rr=BIG
c     Important to use iterative improvement, since the Pade equations
c     tend to be ill-conditioned
1     continue
        rrold=rr
        do j=1,n
          z(j)=x(j)
        enddo
        call mprove(q,qlu,n,indx,y,x)
        rr=0.d0
c       Calculate residual
        do j=1,n
          rr=rr+(z(j)-x(j))**2
        enddo
c     If it is no longer improving, call it quits
      if (rr.lt.rrold) goto 1
      resid=sqrt(rr)
c     Calculate the remaining coefficients
      do k=1,m
        sum=cof(k+1)
        do j=1,k
          sum=sum-x(j)*cof(k-j+1)
        enddo
        v(k)=sum
      enddo 
c     Copy answers to output
      do j=1,m
       cof(j+1)=v(j)
      enddo
      do j=1,n
       cof(m+j+1)=-x(j)
      enddo
c
      return
      end subroutine
