c-------------------------------------------------------------------      
      subroutine calcshift (typ)
c--------------------------------------------------------------------
      use datos, only : x, y, z, multim, nin, 
     & mmin, mmax, mincrem, bmin, bmax, bincrem1, bincrem2, tmin, tmax,
     & tincrem1, tincrem2, tincrem3, ltot, test   
      implicit real*8 (a-h,o-z)  
c......typ is a integer number that is equal to 0,1,2
c......for one-, two- and three-dimensional shift
      integer :: typ    
c.....LOCAL VARIABLES:
      integer :: i, im, ib, it
      real*8 :: ra(3), rb(3), rab(3), r1new(3), r2new(3)
      real*8 :: u(3), v(3), w(3)

c.....Initializations
      im = 0; ib = 0; it = 0
c.....Obtain the vector linking the nuclei 1 and 2
      rab(1) = x(2) - x(1)
      rab(2) = y(2) - y(1)
      rab(3) = z(2) - z(1)
c.....Unitary vector "u" in the direction linking the nuclei
      u = rab/sqrt(dot_product(rab,rab))
c.....Shift multipole moments (See Stone's book: p.32-35)
      if (typ.eq.0) then
       do i = mmin, mmax
        im = im + 1 
c.......Initializate new out betasphere multipole 
c.......moments for each loop
        multim(5:6,0:ltot,0:ltot,1:2) = 0d0
c.......Calculate new centers
        x(3) = x(1) - u(1)*mincrem*i
        y(3) = y(1) - u(2)*mincrem*i
        z(3) = z(1) - u(3)*mincrem*i
        x(4) = x(2) + u(1)*mincrem*i
        y(4) = y(2) + u(2)*mincrem*i
        z(4) = z(2) + u(3)*mincrem*i
c.......Shift out beta sphere multipole moments
        nin = 1 !Coordiantes and OUT multipole moments for atom1
        call shift_mm()
        nin = 2 !Coordinates and OUT multipole moments for atom2
        call shift_mm()
c.......Calculate Coulomb interactions between atoms A and B
        call energy(im)    
c.......Test convergence on 4 interactions: BETA(A)-BETA(B),
c.......OUT(A)-OUT(B),BETA(A)-OUT(B),BETA(B)-OUT(A)
        if (test(1).ne.0.and.test(2).ne.0.and.
     & test(3).ne.0.and.test(4).ne.0) then
         goto 11
        else
         goto 1
        endif
1         continue
       enddo
      else if (typ.eq.1) then 
c..... Radio vectors for nucleus 1 and nucleus 2
       ra(1) = x(1);ra(2) = y(1);ra(3) = z(1)
       rb(1) = x(2);rb(2) = y(2);rb(3) = z(2)
c..... Unitary vector "v" orthogonal to vector "u" (arbitrary selection)
       v(1) = 0d0;v(2) = u(3);v(3) = - u(2)
       v = v/sqrt(dot_product(v,v))
       do i = bmin, bmax
        ib = ib + 1
c.......Initializate new out betasphere multipole 
c.......moments for each loop
        multim(5:6,0:ltot,0:ltot,1:2) = 0d0
c.......Calculate new centers
        r1new = ra - bincrem1*i*u - bincrem2*i*v
        r2new = rb + bincrem1*i*u + bincrem2*i*v
        x(3) = r1new(1)
        y(3) = r1new(2)
        z(3) = r1new(3)
        x(4) = r2new(1)
        y(4) = r2new(2)
        z(4) = r2new(3)
c.......Shift out beta sphere multipole moments
        nin = 1 !Coordiantes and OUT multipole moments for atom1
        call shift_mm()
        nin = 2 !Coordinates and OUT multipole moments for atom2
        call shift_mm()
c.......Calculate Coulomb interactions between atoms A and B
        call energy(ib)    
c.......Test convergence on 4 interactions: BETA(A)-BETA(B),
c.......OUT(A)-OUT(B),BETA(A)-OUT(B),BETA(B)-OUT(A)
        if (test(1).ne.0.and.test(2).ne.0.and.
     & test(3).ne.0.and.test(4).ne.0) then
         goto 11
        else
         goto 2
        endif
2       continue
       enddo
      else if (typ.eq.2) then
c..... Radio vectors for nucleus 1 and nucleus 2
       ra(1) = x(1);ra(2) = y(1);ra(3) = z(1)
       rb(1) = x(2);rb(2) = y(2);rb(3) = z(2)
c..... Unitary vector "v" orthogonal to vector "u" (arbitrary selection)
       v(1) = 0d0;v(2) = u(3);v(3) = -u(2)
       v = v/sqrt(dot_product(v,v))
c..... Unitary vector "w" orthogonal to vectors "u" and "v"
c.....(arbitrary selection in the direction)
        w(1) = 1d0
        w(2) = - u(1)*u(2)/(u(2)**2+u(3)**2)
        w(3) = - u(1)*u(3)/(u(2)**2+u(3)**2) 
        w = w/sqrt(dot_product(w,w))
        do i = tmin, tmax
         it = it + 1 
c........Initializate new out betasphere multipole 
c........moments for each loop
         multim(5:6,0:ltot,0:ltot,1:2) = 0d0
c........Calculate new centers
         r1new = ra - tincrem1*i*u - tincrem2*i*v - tincrem3*i*w
         r2new = rb + tincrem1*i*u + tincrem2*i*v + tincrem3*i*w
         x(3) = r1new(1)
         y(3) = r1new(2)
         z(3) = r1new(3)
         x(4) = r2new(1)
         y(4) = r2new(2)
         z(4) = r2new(3)
c........Shift out beta sphere multipole moments
         nin = 1 !Coordiantes and OUT multipole moments for atom1
         call shift_mm()
         nin = 2 !Coordinates and OUT multipole moments for atom2
         call shift_mm()
c........Calculate Coulomb interactions between atoms A and B
         call energy(it)    
c........Test convergence on 4 interactions: BETA(A)-BETA(B),
c........OUT(A)-OUT(B),BETA(A)-OUT(B),BETA(B)-OUT(A)
         if (test(1).ne.0.and.test(2).ne.0.and.
     & test(3).ne.0.and.test(4).ne.0) then
          goto 11
         else
          goto 3
         endif
3        continue
        enddo
      endif
11    continue
c.....End subroutine                 
      return
      end subroutine

