c-------------------------------------------------------------------------
      subroutine read_multipole() 
c     FUNCTION : Compute both Beta and Out multipole moments for neq1
c                and neq2 no equivalent atoms
c     REMARKS :  [1] The value of first index, i, in multim depends on 
c                    neq1, neq2 and beta and out regions:
c                    * i = 1 <---> neq1, beta multipole moments
c                    * i = 2 <---> neq2, beta multipole moments
c                    * i = 3 <---> neq1, out multipole moments
c                    * i = 4 <---> neq2, out multipole moments     
c                [2] Beta sphere multipole moments include nuclear charge                     
c-------------------------------------------------------------------------
      use datos, only :  x, y, z, xyz, neq1, neq2, eq1, eq2, 
     &                   ltot, charge, multim, brhoqlm, rhoqlm 
      implicit real*8 (a-h,o-z)
c.....LOCAL VARIBLES:  
      integer :: l, k, lkc, lks, i, j
      integer :: nc1, nc2 

c.....Initilizations
      multim=0d0
      nc1 = eq1
      nc2 = eq2
c.....Nuclei positions
      x(1) = xyz(nc1,1)
      x(2) = xyz(nc2,1)
      y(1) = xyz(nc1,2)
      y(2) = xyz(nc2,2)
      z(1) = xyz(nc1,3)
      z(2) = xyz(nc2,3)
c.....Multipole moments
      do l = 0, ltot
       do k = 0, l
        lkc = l*(l+1) + k  
        lks = l*(l+1) - k
        if (l.eq.0) then 
         multim(1,l,k,1) = charge(nc1) - brhoqlm(neq1,0)   
         multim(1,l,k,2) = 0d0 
         multim(2,l,k,1) = charge(nc2) - brhoqlm(neq2,0)
         multim(2,l,k,2) = 0d0
         multim(3,l,k,1) = - rhoqlm(neq1,0)
         multim(3,l,k,2) = 0d0
         multim(4,l,k,1) = - rhoqlm(neq2,0)
         multim(4,l,k,2) = 0d0
        else
         if (k.eq.0) then ! Q_l0 (if k=0 -> lkc=lks)
          multim(1,l,k,1) =  - brhoqlm(neq1,lkc) 
          multim(1,l,k,2) = 0d0
          multim(2,l,k,1) =  - brhoqlm(neq2,lkc)
          multim(2,l,k,2) = 0d0
          multim(3,l,k,1) = - rhoqlm(neq1,lkc)
          multim(3,l,k,2) = 0d0
          multim(4,l,k,1) = - rhoqlm(neq2,lkc)
          multim(4,l,k,2) = 0d0
         else
          multim(1,l,k,1) = - brhoqlm(neq1,lkc) ! Q_lm (m>0)
          multim(2,l,k,1) = - brhoqlm(neq2,lkc)
          multim(3,l,k,1) = - rhoqlm(neq1,lkc)  
          multim(4,l,k,1) = - rhoqlm(neq2,lkc)     
          multim(1,l,k,2) = - brhoqlm(neq1,lks) ! Q_lm (m<0)
          multim(2,l,k,2) = - brhoqlm(neq2,lks)   
          multim(3,l,k,2) = - rhoqlm(neq1,lks)
          multim(4,l,k,2) = - rhoqlm(neq2,lks)
         endif
        endif
        do i = 1, 4
         do j = 1, 2
          if (abs(multim(i,l,k,j)).lt.1d-20) multim(i,l,k,j)=0d0
         enddo
        enddo
       enddo
      enddo
c.....End subroutine
      return
      end subroutine
