      program rholm
c-----------------------------------------------------------------------
c
c
c  rrrrrrr   hhh    hhh  oooooooo  lll       mmmmm  mmmmm            
c rrrrrrrrr  hhh    hhh oooooooooo lll      mmmmmm  mmmmmm               
c rrr    rrr hhh    hhh ooo    ooo lll      mmm mm  mm mmm     
c rrr    rrr hhh    hhh ooo    ooo lll      mmm  m  m  mmm      
c rrr   rrr  hhh    hhh ooo    ooo lll      mmm    m   mmm        
c rrrrrrrrr  hhhhhhhhhh ooo    ooo lll      mmm        mmm        
c rrrrrrr    hhhhhhhhhh ooo    ooo lll      mmm        mmm  
c rrr rrr    hhh    hhh ooo    ooo lll      mmm        mmm        
c rrr  rrr   hhh    hhh ooo    ooo lll      mmm        mmm             
c rrr  rrr   hhh    hhh ooo    ooo lll      mmm        mmm  
c rrr   rrr  hhh    hhh oooooooooo llllllll mmm        mmm   
c rrr    rrr hhh    hhh  oooooooo   llllll  mmm        mmm  
c
c
c       Carlos Jose Fernandez Solano
c       Departamento de Quimica Fisica y Analitica.
c       Facultad de Quimica, Universidad de Oviedo,
c       33006-Oviedo, SPAIN.  
c
c     Auxiliar program of PROMOLDEN code. This code extract Rlm(r)
c     values for the electron density [see A. Martin Pendas and M. A.
c     Blanco and E. Francisco, J. Chem. Phys. 120, 4581 (2004)].
c     
c     This code calculates multipoles moments
c     using a modified Multipolar Expansion (ME).
c     See:
c     Popelier, P. L. A.; Joubert, L.; Kosov, D. S. J. Chem. Phys. A.
c     2001,105,8254-8261.
c
c     This code calculates multipoles moments
c     using a modified Bipolar Expansion (BE).
c     See:
c     Ruedenberg, K. Theoret. Chim. Acta 1967,7,359-366
c     Salmon, L. S.; Birss, F. W.; Ruedenberg, K. J. Chem. Phys.
c     1968,49(10),4293-4300
c     Salmon, L. S. Int. J. Quantum Chem. 1973,7,411-424
c     M. Alvarez Blanco, Ph. D. thesis, Universidad de Oviedo (1997),
c     uRL:htp://web.uniovi.es/qcg/mab/tesis.html.
c
c     This code calculates electrostatic interaction between two atomic
c     basins using ME. Moreover, it can also use BE.
c
c     This code calculates Pade & ERA aproximations for ME.
c     The Rational aproximant Rmn(x) of the function f(x) is defined as
c     a rational fractional expresion of the form:
c     Rmn(x)=Pm(x)/Qn(x)
c     where Pm(x) and Qn(x) are polynomials of degree at most m and n,
c     respectively. The multipole energy, E(1/R), where R is
c     the internuclear distances, can be written like series of 1/R
c     powers.
c     This series is convergent in 1/R<1/r, where r mesasures the
c     distance between two charge elements (with respect to the global
c     origin). A priori, one can obtain convergence in a much wider
c     region using Pade aproximant.
c     See:
c     G. Baker and P. Graves-Morris, "Pade Approximants",Vol. 59
c     of "Encyclopedia of Mathematics and its Aplications".
c     V. I. Kukulin, V. M. Krasnopol'sky, and J. Horacek. "Theory
c     of Resonances, Principles and Applications" (Kluwer Academic,
c     Dordetcht, 1989), Sec. 1.2.
c     A. Raltson, "A First Course in Numerical Analysis" (McGraw-Hill,
c     New York, 1965), Secs. 7.3, 7.4 and 7.7.
c     W. H. Press, S. A. Teukolsky, W. T. Vetterling and B. P. Flannery,
c     "Numerical Recipes in Fortran" (Cambridge University Press), 2nd
c     edition.
c
c     This code shifts Qlm multipole moments. It used the Joubert's code to shift
c     the moments. Finally, it calculated the Coulomb energy between the atoms
c     [see M. Rafat and P.L.A. Popelier, J. Chem. Phys. 124, 144102(2006)].
c
c     This code computes the rotation matrices for RSHs. Then, it uses
c     rotor matrices to rotate Rlm(r) functions.
c
c
c     RUN THE PROGRAM:  
c     rholm  inputfile
c
c----------------------------------------------------------------------
c
      use datos, only : faterr, arg, larg, marg, stdin1 
      use libreria, only : error, getopt, leng
      implicit real*8 (a-h,o-z)
      character*1 :: null
      logical :: lflg(1), lopt(1)
      character*1 :: optarg(1)
      
c
      null = char(0)
      lflg(1) = .false. 
      lopt(1) = .false.
      optarg(1) = null      
      llmax = 0 
c
c-----parse command line
c
      if (.not. getopt(arg, larg, marg, null, lflg, 0,
     &                 null, lopt, 0, optarg))
     &   call error ('rholm', 'run program as: rholm inputfile', faterr)
c
c-----read & interpret input file:
c
       if (larg(1)) then
         open (stdin1, file=arg(1)(1:leng(arg(1))), status='old',
     & action='read', iostat=nios)
         if (nios.ne.0)
     &     call error ('rholm', 'error while opening '//
     &arg(1)(1:leng(arg(1))), faterr)
         call shellrholm ()
         close (stdin1)
       else
         call error ('rholm', 'run program as: rholm inputfile', faterr)
       endif
c
c-----End of the program
c
      end
