      subroutine shift_mm() 

      use datos, only : ltot, nin, multim, x, y, z, slm2, il02, warning
      use libreria, only : bol, rsh, calc_newmm, error, itoa, leng
      implicit real*8 (a-h,o-z)
*     ********************************************************
*     PURPOSE : SHIFT MULTIPOLE MOMENTS
*     (See Stone's book : p.32-35)
*     ********************************************************
c.....LOCAL VARIABLES:
      real*8 :: oldmm1(0:ltot,0:ltot,2)
      real*8 :: newmm1(0:ltot,0:ltot,2)
      real*8 :: newmm2(0:ltot,0:ltot,2)
      real*8 :: devlki(0:ltot,0:ltot,2)
      real*8 :: rcart(3)
      real*8 :: rad, theta, phi
      integer :: imax, l1, k1, i
      character*16 :: lnum, knum
      character*1 :: inum
      real*8, parameter :: TINY = 1d-20
      real*8, parameter :: EPSFRAC = 1d-6

c.....Initializations
      newmm1=0d0;newmm2=0d0;oldmm1=0d0
      do l1=0,ltot
       do k1=0,l1
        if (k1.eq.0) then
         imax=1
        else
         imax=2
        endif
        do i=1,imax
         devlki(l1,k1,i)=0d0
         oldmm1(l1,k1,i)=multim(nin+2,l1,k1,i)
        enddo
       enddo
      enddo

c.....Obtain the shift vector
c.....Atom A shifts in the direction of the vector shift,
c.....but atom B shifts in the opposite direction 
      rcart(1)=x(nin)-x(nin+2)
      rcart(2)=y(nin)-y(nin+2)
      rcart(3)=z(nin)-z(nin+2)
c.....Transform the cartesians coordinates of shift vector to polar 
c.....spherical coordinates and obtain new multipole moments for OUT(A)
c.....or OUT(B)
      call bol(rcart,rad,theta,phi)
      call rsh(theta,phi,slm2,il02,ltot) !Obtain Slmc and Slms
      call calc_newmm(newmm2,oldmm1,rad)
c.....Recalculate the multipole moments in the initial position
      rcart(1)=-rcart(1)
      rcart(2)=-rcart(2)
      rcart(3)=-rcart(3)
      call bol(rcart,rad,theta,phi)
      call rsh(theta,phi,slm2,il02,ltot) !Obtain Slmc and Slms 
      call calc_newmm(newmm1,newmm2,rad)
      !Note: newmm1 must be very similar to oldmm1
      do l1=0,ltot
       do k1=0,l1
        if (k1.eq.0) then
         imax=1
        else
         imax=2
        endif
        do i=1,imax
c........Calculate relative deviation
         if (abs(oldmm1(l1,k1,i)).gt.TINY) then
          devlki(l1,k1,i)=abs(newmm1(l1,k1,i)-oldmm1(l1,k1,i))
     &                 /abs(oldmm1(l1,k1,i))
          if (devlki(l1,k1,i).gt.0.5d0) then
           lnum=itoa(l1)
           knum=itoa(k1)
           if (i.eq.1) then ! Qlmc
            inum='c'
           else ! Qlms
            inum='s'
           endif 
           if (nin.eq.1) then ! atom A
            call error ('shift_mm','Relative deviation for shift
     & Q('//lnum(1:leng(lnum))//','//knum(1:leng(knum))//','//inum//
     & ') is greather than 50% in atom A', warning)
           else ! atom B
            call error ('shift_mm','Relative deviation for shift
     & Q('//lnum(1:leng(lnum))//','//knum(1:leng(knum))//','//inum//
     & ') is greather than 50% in atom B', warning) 
           endif
          endif
         else
          devlki(l1,k1,i)=abs(newmm1(l1,k1,i)-oldmm1(l1,k1,i))
          if (devlki(l1,k1,i).gt.EPSFRAC) then
           lnum=itoa(l1)
           knum=itoa(k1)
           if (i.eq.1) then ! Qlmc
            inum='c'
           else ! Qlms
            inum='s'
           endif
           if (nin.eq.1) then ! atom A
            call error ('shift_mm','Absolute deviation for shift
     & Q('//lnum(1:leng(lnum))//','//knum(1:leng(knum))//','//inum//
     & ') is greather than 1d-6 in atom A', warning)
           else ! atom B
            call error ('shift_mm','Absolute deviation for shift
     & Q('//lnum(1:leng(lnum))//','//knum(1:leng(knum))//','//inum//
     & ') is greather than 1d-6 in atom B', warning)
           endif
          endif
         endif
c........Reallocation of shift multipole moments
         multim(nin+4,l1,k1,i)=newmm2(l1,k1,i)
        enddo
       enddo
      enddo
c                 
      return
      end subroutine
